/**
 * 将base64图片转换成二进制对象
 * @param {Object} baseStr
 * @param {Object} format 例如："image/jpeg"
 */
var convertBase64ToBlob = function(baseStr, format) {
	var code = window.atob(baseStr.split(",")[1]);
	var aBuffer = new window.ArrayBuffer(code.length);
	var uBuffer = new window.Uint8Array(aBuffer)
	for (var i = 0; i < code.length; i++) {
		uBuffer[i] = code.charCodeAt(i);
	}
	var Builder = window.WebKitBlobBuilder || window.MozBlobBuilder || window.BlobBuilder || window.MSBlobBuilder;
	if (Builder) {
		var builder = new Builder;
		builder.append(uBuffer);
		return builder.getBlob(format);
	} else {
		return new window.Blob([uBuffer], {
			type : format
		});
	}
};
/**
 * 自动根据最大w h获取期待的w h
 * @param {Object} img
 * @param {Object} maxWidth
 * @param {Object} maxWidth
 */
var targetImgSize = function(img, maxWidth, maxHeight) {
	var _img_info = {
		w : img.width,
		h : img.height
	};

	var _resize_info = {
		w : 0,
		h : 0
	};
	if (_img_info.w <= maxWidth && _img_info.h <= maxWidth) {
		return _img_info;
	} else {
		var _percent_scale = parseFloat(_img_info.w / _img_info.h);

		var _size_by_mw = {
			w : maxWidth,
			h : parseInt(maxWidth / _percent_scale)
		};
		var _size_by_mh = {
			w : parseInt(maxHeight * _percent_scale),
			h : maxHeight
		};
		if (_size_by_mw.h <= maxHeight) {
			return _size_by_mw;
		}
		if (_size_by_mh.w <= maxWidth) {
			return _size_by_mh;
		}

		return {
			w : maxWidth,
			h : maxHeight
		};
	}

};
var compressBase64 = function(base64data, maxWidth, maxHeight, callback) {
	var canvas = document.createElement("canvas");
	var ctx = canvas.getContext('2d');
	var img = new Image();
	img.src = base64data;
	img.onload = function() {
		var target = targetImgSize(img, maxWidth, maxHeight);
		console.log('计算后的W：' + target.w);
		console.log('计算后的H：' + target.h);
		canvas.width = this.width;
		canvas.height = this.height;

		ctx.drawImage(this, //当前图片
		0, //sourceX,
		0, //sourceY,
		this.width, //sourceWidth,
		this.height, //sourceHeight,
		0, //destX,
		0, //destY,
		target.w, //destWidth,
		target.h //destHeight
		);

		//--获取base64字符串及canvas对象传给success函数。
		var base64str = canvas.toDataURL("image/png");
		if (callback) {
			callback(base64str);
		}
		canvas = null;
	};

}